==> haskell-data-textual-0.3.0.2-73-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-6PtNhn1GHzlCcvA4g8a4dF
key: data-textual-0.3.0.2-6PtNhn1GHzlCcvA4g8a4dF
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
abi: 02dedd04b3a01e1b26c68c4c836189c5
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-textual-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-6PtNhn1GHzlCcvA4g8a4dF
depends:
    base-4.11.1.0 bytestring-0.10.8.2 text-1.2.3.0
    text-latin1-0.3.1-DWrBe0EKJi1CNKTGJ7yOZG
    text-printer-0.5-KfkEpmi52eH1RUGTLZYQg3
    parsers-0.12.9-LxMgMM1WdwxA4SaFpxpOmn
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             text-latin1-0.3.1-DWrBe0EKJi1CNKTGJ7yOZG=a32ae024d8ca0173f507b0a7ab70686f
             text-printer-0.5-KfkEpmi52eH1RUGTLZYQg3=611c3e6eaf60e47d7419aeb7344d21cd
             parsers-0.12.9-LxMgMM1WdwxA4SaFpxpOmn=caef24b1170c2fa24259b679fc10480e
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-textual-0.3.0.2-74-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-IWMTRPGvtDo7Bo6RsKvTNc
key: data-textual-0.3.0.2-IWMTRPGvtDo7Bo6RsKvTNc
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
abi: 8721b031bbff2dcddeaf000eae83023f
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-textual-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-IWMTRPGvtDo7Bo6RsKvTNc
depends:
    base-4.11.1.0 bytestring-0.10.8.2 text-1.2.3.0
    text-latin1-0.3.1-DWrBe0EKJi1CNKTGJ7yOZG
    text-printer-0.5-KfkEpmi52eH1RUGTLZYQg3
    parsers-0.12.9-DwEGlZPHj5dGez2EUdaiuN
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             text-latin1-0.3.1-DWrBe0EKJi1CNKTGJ7yOZG=a32ae024d8ca0173f507b0a7ab70686f
             text-printer-0.5-KfkEpmi52eH1RUGTLZYQg3=611c3e6eaf60e47d7419aeb7344d21cd
             parsers-0.12.9-DwEGlZPHj5dGez2EUdaiuN=a53522c489f8b093913c80c087926495
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
